import { IOpenIdConnectProvider, ISamlProvider, IRole } from 'aws-cdk-lib/aws-iam';
import { Resource, IResource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { IdentityPoolRoleMapping } from './identitypool-role-attachment';
import { IUserPoolAuthenticationProvider } from './identitypool-user-pool-authentication-provider';
/**
 * (experimental) Represents a Cognito IdentityPool.
 *
 * @experimental
 */
export interface IIdentityPool extends IResource {
    /**
     * (experimental) The id of the Identity Pool in the format REGION:GUID.
     *
     * @experimental
     * @attribute true
     */
    readonly identityPoolId: string;
    /**
     * (experimental) The ARN of the Identity Pool.
     *
     * @experimental
     * @attribute true
     */
    readonly identityPoolArn: string;
    /**
     * (experimental) Name of the Identity Pool.
     *
     * @experimental
     * @attribute true
     */
    readonly identityPoolName: string;
}
/**
 * (experimental) Props for the IdentityPool construct.
 *
 * @experimental
 */
export interface IdentityPoolProps {
    /**
     * (experimental) The name of the Identity Pool.
     *
     * @default - automatically generated name by CloudFormation at deploy time
     * @experimental
     */
    readonly identityPoolName?: string;
    /**
     * (experimental) The Default Role to be assumed by Authenticated Users.
     *
     * @default - A Default Authenticated Role will be added
     * @experimental
     */
    readonly authenticatedRole?: IRole;
    /**
     * (experimental) The Default Role to be assumed by Unauthenticated Users.
     *
     * @default - A Default Unauthenticated Role will be added
     * @experimental
     */
    readonly unauthenticatedRole?: IRole;
    /**
     * (experimental) Wwhether the identity pool supports unauthenticated logins.
     *
     * @default - false
     * @experimental
     */
    readonly allowUnauthenticatedIdentities?: boolean;
    /**
     * (experimental) Rules for mapping roles to users.
     *
     * @default - no Role Mappings
     * @experimental
     */
    readonly roleMappings?: IdentityPoolRoleMapping[];
    /**
     * (experimental) Enables the Basic (Classic) authentication flow.
     *
     * @default - Classic Flow not allowed
     * @experimental
     */
    readonly allowClassicFlow?: boolean;
    /**
     * (experimental) Authentication providers for using in identity pool.
     *
     * @default - No Authentication Providers passed directly to Identity Pool
     * @experimental
     */
    readonly authenticationProviders?: IdentityPoolAuthenticationProviders;
}
/**
 * (experimental) Types of Identity Pool Login Providers.
 *
 * @experimental
 */
export declare enum IdentityPoolProviderType {
    /**
     * (experimental) Facebook Provider type.
     *
     * @experimental
     */
    FACEBOOK = "Facebook",
    /**
     * (experimental) Google Provider Type.
     *
     * @experimental
     */
    GOOGLE = "Google",
    /**
     * (experimental) Amazon Provider Type.
     *
     * @experimental
     */
    AMAZON = "Amazon",
    /**
     * (experimental) Apple Provider Type.
     *
     * @experimental
     */
    APPLE = "Apple",
    /**
     * (experimental) Twitter Provider Type.
     *
     * @experimental
     */
    TWITTER = "Twitter",
    /**
     * (experimental) Digits Provider Type.
     *
     * @experimental
     */
    DIGITS = "Digits",
    /**
     * (experimental) Open Id Provider Type.
     *
     * @experimental
     */
    OPEN_ID = "OpenId",
    /**
     * (experimental) Saml Provider Type.
     *
     * @experimental
     */
    SAML = "Saml",
    /**
     * (experimental) User Pool Provider Type.
     *
     * @experimental
     */
    USER_POOL = "UserPool",
    /**
     * (experimental) Custom Provider Type.
     *
     * @experimental
     */
    CUSTOM = "Custom"
}
/**
 * (experimental) Keys for Login Providers - correspond to client id's of respective federation identity providers.
 *
 * @experimental
 */
export declare class IdentityPoolProviderUrl {
    /** type of Provider Url */
    readonly type: IdentityPoolProviderType;
    /** value of Provider Url */
    readonly value: string;
    /**
     * (experimental) Facebook Provider Url.
     *
     * @experimental
     */
    static readonly FACEBOOK: IdentityPoolProviderUrl;
    /**
     * (experimental) Google Provider Url.
     *
     * @experimental
     */
    static readonly GOOGLE: IdentityPoolProviderUrl;
    /**
     * (experimental) Amazon Provider Url.
     *
     * @experimental
     */
    static readonly AMAZON: IdentityPoolProviderUrl;
    /**
     * (experimental) Apple Provider Url.
     *
     * @experimental
     */
    static readonly APPLE: IdentityPoolProviderUrl;
    /**
     * (experimental) Twitter Provider Url.
     *
     * @experimental
     */
    static readonly TWITTER: IdentityPoolProviderUrl;
    /**
     * (experimental) Digits Provider Url.
     *
     * @experimental
     */
    static readonly DIGITS: IdentityPoolProviderUrl;
    /**
     * (experimental) OpenId Provider Url.
     *
     * @experimental
     */
    static openId(url: string): IdentityPoolProviderUrl;
    /**
     * (experimental) Saml Provider Url.
     *
     * @experimental
     */
    static saml(url: string): IdentityPoolProviderUrl;
    /**
     * (experimental) User Pool Provider Url.
     *
     * @experimental
     */
    static userPool(url: string): IdentityPoolProviderUrl;
    /**
     * (experimental) Custom Provider Url.
     *
     * @experimental
     */
    static custom(url: string): IdentityPoolProviderUrl;
    /**
     * @param type type of Provider Url.
     * @param value value of Provider Url.
     * @experimental
     */
    constructor(
    /** type of Provider Url */
    type: IdentityPoolProviderType, 
    /** value of Provider Url */
    value: string);
}
/**
 * (experimental) Login Provider for Identity Federation using Amazon Credentials.
 *
 * @experimental
 */
export interface IdentityPoolAmazonLoginProvider {
    /**
     * (experimental) App Id for Amazon Identity Federation.
     *
     * @experimental
     */
    readonly appId: string;
}
/**
 * (experimental) Login Provider for Identity Federation using Facebook Credentials.
 *
 * @experimental
 */
export interface IdentityPoolFacebookLoginProvider {
    /**
     * (experimental) App Id for Facebook Identity Federation.
     *
     * @experimental
     */
    readonly appId: string;
}
/**
 * (experimental) Login Provider for Identity Federation using Apple Credentials.
 *
 * @experimental
 */
export interface IdentityPoolAppleLoginProvider {
    /**
     * (experimental) App Id for Apple Identity Federation.
     *
     * @experimental
     */
    readonly servicesId: string;
}
/**
 * (experimental) Login Provider for Identity Federation using Google Credentials.
 *
 * @experimental
 */
export interface IdentityPoolGoogleLoginProvider {
    /**
     * (experimental) App Id for Google Identity Federation.
     *
     * @experimental
     */
    readonly clientId: string;
}
/**
 * (experimental) Login Provider for Identity Federation using Twitter Credentials.
 *
 * @experimental
 */
export interface IdentityPoolTwitterLoginProvider {
    /**
     * (experimental) App Id for Twitter Identity Federation.
     *
     * @experimental
     */
    readonly consumerKey: string;
    /**
     * (experimental) App Secret for Twitter Identity Federation.
     *
     * @experimental
     */
    readonly consumerSecret: string;
}
/**
 * (experimental) Login Provider for Identity Federation using Digits Credentials.
 *
 * @experimental
 */
export interface IdentityPoolDigitsLoginProvider extends IdentityPoolTwitterLoginProvider {
}
/**
 * (experimental) External Identity Providers To Connect to User Pools and Identity Pools.
 *
 * @experimental
 */
export interface IdentityPoolProviders {
    /**
     * (experimental) App Id for Facebook Identity Federation.
     *
     * @default - No Facebook Authentication Provider used without OpenIdConnect or a User Pool
     * @experimental
     */
    readonly facebook?: IdentityPoolFacebookLoginProvider;
    /**
     * (experimental) Client Id for Google Identity Federation.
     *
     * @default - No Google Authentication Provider used without OpenIdConnect or a User Pool
     * @experimental
     */
    readonly google?: IdentityPoolGoogleLoginProvider;
    /**
     * (experimental) App Id for Amazon Identity Federation.
     *
     * @default -  No Amazon Authentication Provider used without OpenIdConnect or a User Pool
     * @experimental
     */
    readonly amazon?: IdentityPoolAmazonLoginProvider;
    /**
     * (experimental) Services Id for Apple Identity Federation.
     *
     * @default - No Apple Authentication Provider used without OpenIdConnect or a User Pool
     * @experimental
     */
    readonly apple?: IdentityPoolAppleLoginProvider;
    /**
     * (experimental) Consumer Key and Secret for Twitter Identity Federation.
     *
     * @default - No Twitter Authentication Provider used without OpenIdConnect or a User Pool
     * @experimental
     */
    readonly twitter?: IdentityPoolTwitterLoginProvider;
    /**
     * (experimental) Consumer Key and Secret for Digits Identity Federation.
     *
     * @default - No Digits Authentication Provider used without OpenIdConnect or a User Pool
     * @experimental
     */
    readonly digits?: IdentityPoolDigitsLoginProvider;
}
/**
 * (experimental) Authentication providers for using in identity pool.
 *
 * @see https://docs.aws.amazon.com/cognito/latest/developerguide/external-identity-providers.html
 * @experimental
 */
export interface IdentityPoolAuthenticationProviders extends IdentityPoolProviders {
    /**
     * (experimental) The User Pool Authentication Providers associated with this Identity Pool.
     *
     * @default - no User Pools Associated
     * @experimental
     */
    readonly userPools?: IUserPoolAuthenticationProvider[];
    /**
     * (experimental) The OpenIdConnect Provider associated with this Identity Pool.
     *
     * @default - no OpenIdConnectProvider
     * @experimental
     */
    readonly openIdConnectProviders?: IOpenIdConnectProvider[];
    /**
     * (experimental) The Security Assertion Markup Language Provider associated with this Identity Pool.
     *
     * @default - no SamlProvider
     * @experimental
     */
    readonly samlProviders?: ISamlProvider[];
    /**
     * (experimental) The Developer Provider Name to associate with this Identity Pool.
     *
     * @default - no Custom Provider
     * @experimental
     */
    readonly customProvider?: string;
}
/**
 * (experimental) Define a Cognito Identity Pool.
 *
 * @experimental
 * @resource AWS::Cognito::IdentityPool
 */
export declare class IdentityPool extends Resource implements IIdentityPool {
    /**
     * (experimental) Import an existing Identity Pool from its id.
     *
     * @experimental
     */
    static fromIdentityPoolId(scope: Construct, id: string, identityPoolId: string): IIdentityPool;
    /**
     * (experimental) Import an existing Identity Pool from its Arn.
     *
     * @experimental
     */
    static fromIdentityPoolArn(scope: Construct, id: string, identityPoolArn: string): IIdentityPool;
    /**
     * (experimental) The id of the Identity Pool in the format REGION:GUID.
     *
     * @experimental
     * @attribute true
     */
    readonly identityPoolId: string;
    /**
     * (experimental) The ARN of the Identity Pool.
     *
     * @experimental
     * @attribute true
     */
    readonly identityPoolArn: string;
    /**
     * (experimental) The name of the Identity Pool.
     *
     * @experimental
     * @attribute true
     */
    readonly identityPoolName: string;
    /**
     * (experimental) Default role for authenticated users.
     *
     * @experimental
     */
    readonly authenticatedRole: IRole;
    /**
     * (experimental) Default role for unauthenticated users.
     *
     * @experimental
     */
    readonly unauthenticatedRole: IRole;
    /**
     * List of Identity Providers added in constructor for use with property overrides
     */
    private cognitoIdentityProviders;
    /**
     * Running count of added role attachments
     */
    private roleAttachmentCount;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props?: IdentityPoolProps);
    /**
     * (experimental) Add a User Pool to the IdentityPool and configure User Pool Client to handle identities.
     *
     * @experimental
     */
    addUserPoolAuthentication(userPool: IUserPoolAuthenticationProvider): void;
    /**
     * (experimental) Adds Role Mappings to Identity Pool.
     *
     * @experimental
     */
    addRoleMappings(...roleMappings: IdentityPoolRoleMapping[]): void;
    /**
     * Configure Default Roles For Identity Pool
     */
    private configureDefaultRole;
    private configureDefaultGrantPrincipal;
}
